@@ -1,8 +1,6 @@
 #!/usr/bin/env python
 # -*- encoding: utf-8 -*-
 #
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-#
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 # All Rights Reserved.
 #
@@ -52,7 +50,7 @@ def main():
     # make sure we have tripleo-heat-templates:
     heat_template_path = CONF.tht_local_dir
     try:
-        templates = os.listdir(heat_template_path)
+        os.listdir(heat_template_path)
     except OSError:
         LOG.info("Can't find local tripleo-heat-template files at %s"
                   % (heat_template_path))
